@@ -61,13 +61,10 @@ $config->setFinder($finder)
                 'yield_from',
             ],
         ],
-        'braces' => [
-            'position_after_anonymous_constructs' => 'next',
-        ],
         'cast_spaces' => true,
         'class_attributes_separation' => [
             'elements' => [
-                'const' => 'one',
+                'const' => 'none',
                 'method' => 'one',
                 'property' => 'one'
             ]
@@ -80,7 +77,14 @@ $config->setFinder($finder)
         'compact_nullable_typehint' => true,
         'concat_space' => ['spacing' => 'one'],
         'constant_case' => true,
+        'control_structure_braces' => true,
+        'control_structure_continuation_position' => true,
+        'curly_braces_position' => [
+            'anonymous_functions_opening_brace' => 'next_line_unless_newline_at_signature_end',
+            'anonymous_classes_opening_brace' => 'next_line_unless_newline_at_signature_end',
+        ],
         'declare_equal_normalize' => ['space' => 'none'],
+        'declare_parentheses' => true,
         'declare_strict_types' => true,
         'dir_constant' => true,
         'echo_tag_syntax' => true,
@@ -153,6 +157,7 @@ $config->setFinder($finder)
         'no_leading_import_slash' => true,
         'no_leading_namespace_whitespace' => true,
         'no_mixed_echo_print' => ['use' => 'print'],
+        'no_multiple_statements_per_line' => true,
         'no_multiline_whitespace_around_double_arrow' => true,
         'no_null_property_initialization' => true,
         'no_php4_constructor' => true,
@@ -278,11 +283,12 @@ $config->setFinder($finder)
         'single_import_per_statement' => true,
         'single_line_after_imports' => true,
         'single_quote' => true,
-        'single_space_after_construct' => true,
+        'single_space_around_construct' => true,
         'single_trait_insert_per_statement' => true,
         'space_after_semicolon' => true,
         'standardize_increment' => true,
         'standardize_not_equals' => true,
+        'statement_indentation' => true,
         'static_lambda' => true,
         'strict_param' => true,
         'string_line_ending' => true,
