@@ -10,10 +10,16 @@
 namespace PHPUnit\Framework;
 
 use const PHP_EOL;
+use function class_exists;
 use function count;
+use function extension_loaded;
 use function function_exists;
 use function get_class;
 use function sprintf;
+use function xdebug_get_monitored_functions;
+use function xdebug_is_debugger_active;
+use function xdebug_start_function_monitor;
+use function xdebug_stop_function_monitor;
 use AssertionError;
 use Countable;
 use Error;
@@ -452,7 +458,7 @@ final class TestResult implements Countable
 
             $this->passed[$key] = [
                 'result' => $test->getResult(),
-                'size'   => \PHPUnit\Util\Test::getSize(
+                'size'   => TestUtil::getSize(
                     $class,
                     $test->getName(false)
                 ),
@@ -636,12 +642,15 @@ final class TestResult implements Countable
     {
         Assert::resetCount();
 
+        $size = TestUtil::UNKNOWN;
+
         if ($test instanceof TestCase) {
             $test->setRegisterMockObjectsFromTestArgumentsRecursively(
                 $this->registerMockObjectsFromTestArgumentsRecursively
             );
 
             $isAnyCoverageRequired = TestUtil::requiresCodeCoverageDataCollection($test);
+            $size                  = $test->getSize();
         }
 
         $error      = false;
@@ -676,7 +685,7 @@ final class TestResult implements Countable
         $monitorFunctions = $this->beStrictAboutResourceUsageDuringSmallTests &&
                             !$test instanceof ErrorTestCase &&
                             !$test instanceof WarningTestCase &&
-                            $test->getSize() === \PHPUnit\Util\Test::SMALL &&
+                            $size === TestUtil::SMALL &&
                             function_exists('xdebug_start_function_monitor');
 
         if ($monitorFunctions) {
@@ -692,29 +701,26 @@ final class TestResult implements Countable
 
             if (!$test instanceof ErrorTestCase &&
                 !$test instanceof WarningTestCase &&
-                $this->enforceTimeLimit &&
-                ($this->defaultTimeLimit || $test->getSize() != \PHPUnit\Util\Test::UNKNOWN) &&
+                $this->shouldTimeLimitBeEnforced($size) &&
                 $invoker->canInvokeWithTimeout()) {
-                switch ($test->getSize()) {
-                    case \PHPUnit\Util\Test::SMALL:
+                switch ($size) {
+                    case TestUtil::SMALL:
                         $_timeout = $this->timeoutForSmallTests;
 
                         break;
 
-                    case \PHPUnit\Util\Test::MEDIUM:
+                    case TestUtil::MEDIUM:
                         $_timeout = $this->timeoutForMediumTests;
 
                         break;
 
-                    case \PHPUnit\Util\Test::LARGE:
+                    case TestUtil::LARGE:
                         $_timeout = $this->timeoutForLargeTests;
 
                         break;
 
-                    case \PHPUnit\Util\Test::UNKNOWN:
+                    default:
                         $_timeout = $this->defaultTimeLimit;
-
-                        break;
                 }
 
                 $invoker->invoke([$test, 'runBare'], [], $_timeout);
@@ -751,9 +757,11 @@ final class TestResult implements Countable
                 sprintf(
                     '%s in %s:%s',
                     $e->getMessage(),
-                    $frame['file'],
-                    $frame['line']
-                )
+                    $frame['file'] ?? $e->getFile(),
+                    $frame['line'] ?? $e->getLine()
+                ),
+                0,
+                $e
             );
         } catch (Warning $e) {
             $warning = true;
@@ -796,6 +804,7 @@ final class TestResult implements Countable
         }
 
         if ($this->beStrictAboutTestsThatDoNotTestAnything &&
+            !$test->doesNotPerformAssertions() &&
             $test->getNumAssertions() === 0) {
             $risky = true;
         }
@@ -829,12 +838,12 @@ final class TestResult implements Countable
 
             if ($append && $test instanceof TestCase) {
                 try {
-                    $linesToBeCovered = \PHPUnit\Util\Test::getLinesToBeCovered(
+                    $linesToBeCovered = TestUtil::getLinesToBeCovered(
                         get_class($test),
                         $test->getName(false)
                     );
 
-                    $linesToBeUsed = \PHPUnit\Util\Test::getLinesToBeUsed(
+                    $linesToBeUsed = TestUtil::getLinesToBeUsed(
                         get_class($test),
                         $test->getName(false)
                     );
@@ -894,7 +903,7 @@ final class TestResult implements Countable
             } catch (ReflectionException $e) {
                 throw new Exception(
                     $e->getMessage(),
-                    (int) $e->getCode(),
+                    $e->getCode(),
                     $e
                 );
             }
@@ -909,7 +918,7 @@ final class TestResult implements Countable
                 } catch (ReflectionException $e) {
                     throw new Exception(
                         $e->getMessage(),
-                        (int) $e->getCode(),
+                        $e->getCode(),
                         $e
                     );
                 }
@@ -1286,4 +1295,29 @@ final class TestResult implements Countable
     {
         $this->warnings[] = new TestFailure($test, $t);
     }
+
+    private function shouldTimeLimitBeEnforced(int $size): bool
+    {
+        if (!$this->enforceTimeLimit) {
+            return false;
+        }
+
+        if (!(($this->defaultTimeLimit || $size !== TestUtil::UNKNOWN))) {
+            return false;
+        }
+
+        if (!extension_loaded('pcntl')) {
+            return false;
+        }
+
+        if (!class_exists(Invoker::class)) {
+            return false;
+        }
+
+        if (extension_loaded('xdebug') && xdebug_is_debugger_active()) {
+            return false;
+        }
+
+        return true;
+    }
 }
