@@ -7,6 +7,8 @@
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
+namespace PHPUnit\TestFixture;
+
 use PHPUnit\Framework\TestCase;
 
 class DependencyOnClassTest extends TestCase
@@ -14,7 +16,7 @@ class DependencyOnClassTest extends TestCase
     /**
      * Guard support for using annotations to depend on a whole successful TestSuite.
      *
-     * @depends DependencySuccessTest::class
+     * @depends PHPUnit\TestFixture\DependencySuccessTest::class
      *
      * @see https://github.com/sebastianbergmann/phpunit/issues/3519
      */
@@ -26,7 +28,7 @@ class DependencyOnClassTest extends TestCase
     /**
      * Guard support for using annotations to depend on a whole failing TestSuite.
      *
-     * @depends DependencyFailureTest::class
+     * @depends PHPUnit\TestFixture\DependencyFailureTest::class
      *
      * @see https://github.com/sebastianbergmann/phpunit/issues/3519
      */
