@@ -34,7 +34,6 @@ use DateTime;
 use DateTimeZone;
 use PHPUnit\TestFixture\Author;
 use PHPUnit\TestFixture\Book;
-use PHPUnit\TestFixture\ClassWithNonPublicAttributes;
 use PHPUnit\TestFixture\ClassWithToString;
 use PHPUnit\TestFixture\ObjectEquals\ValueObject;
 use PHPUnit\TestFixture\SampleArrayAccess;
@@ -683,76 +682,6 @@ XML;
         $this->assertFileIsWritable(__DIR__ . DIRECTORY_SEPARATOR . 'NotExisting');
     }
 
-    public function testAssertObjectHasAttribute(): void
-    {
-        $o = new Author('Terry Pratchett');
-
-        $this->assertObjectHasAttribute('name', $o);
-
-        $this->expectException(AssertionFailedError::class);
-
-        $this->assertObjectHasAttribute('foo', $o);
-    }
-
-    public function testAssertObjectHasAttributeNumericAttribute(): void
-    {
-        $object           = new stdClass;
-        $object->{'2020'} = 'Tokyo';
-
-        $this->assertObjectHasAttribute('2020', $object);
-
-        $this->expectException(AssertionFailedError::class);
-
-        $this->assertObjectHasAttribute('2018', $object);
-    }
-
-    public function testAssertObjectHasAttributeMultiByteAttribute(): void
-    {
-        $object         = new stdClass;
-        $object->{'東京'} = 2020;
-
-        $this->assertObjectHasAttribute('東京', $object);
-
-        $this->expectException(AssertionFailedError::class);
-
-        $this->assertObjectHasAttribute('長野', $object);
-    }
-
-    public function testAssertObjectNotHasAttribute(): void
-    {
-        $o = new Author('Terry Pratchett');
-
-        $this->assertObjectNotHasAttribute('foo', $o);
-
-        $this->expectException(AssertionFailedError::class);
-
-        $this->assertObjectNotHasAttribute('name', $o);
-    }
-
-    public function testAssertObjectNotHasAttributeNumericAttribute(): void
-    {
-        $object           = new stdClass;
-        $object->{'2020'} = 'Tokyo';
-
-        $this->assertObjectNotHasAttribute('2018', $object);
-
-        $this->expectException(AssertionFailedError::class);
-
-        $this->assertObjectNotHasAttribute('2020', $object);
-    }
-
-    public function testAssertObjectNotHasAttributeMultiByteAttribute(): void
-    {
-        $object         = new stdClass;
-        $object->{'東京'} = 2020;
-
-        $this->assertObjectNotHasAttribute('長野', $object);
-
-        $this->expectException(AssertionFailedError::class);
-
-        $this->assertObjectNotHasAttribute('東京', $object);
-    }
-
     public function testAssertFinite(): void
     {
         $this->assertFinite(1);
@@ -958,216 +887,6 @@ XML;
         $this->assertLessThanOrEqual(1, 2);
     }
 
-    public function testAssertClassHasAttributeThrowsExceptionIfAttributeNameIsNotValid(): void
-    {
-        $this->expectException(Exception::class);
-
-        $this->assertClassHasAttribute('1', ClassWithNonPublicAttributes::class);
-    }
-
-    public function testAssertClassHasAttributeThrowsExceptionIfClassDoesNotExist(): void
-    {
-        $this->expectException(Exception::class);
-
-        $this->assertClassHasAttribute('attribute', ClassThatDoesNotExist::class);
-    }
-
-    public function testAssertClassNotHasAttributeThrowsExceptionIfAttributeNameIsNotValid(): void
-    {
-        $this->expectException(Exception::class);
-
-        $this->assertClassNotHasAttribute('1', ClassWithNonPublicAttributes::class);
-    }
-
-    public function testAssertClassNotHasAttributeThrowsExceptionIfClassDoesNotExist(): void
-    {
-        $this->expectException(Exception::class);
-
-        $this->assertClassNotHasAttribute('attribute', ClassThatDoesNotExist::class);
-    }
-
-    public function testAssertClassHasStaticAttributeThrowsExceptionIfAttributeNameIsNotValid(): void
-    {
-        $this->expectException(Exception::class);
-
-        $this->assertClassHasStaticAttribute('1', ClassWithNonPublicAttributes::class);
-    }
-
-    public function testAssertClassHasStaticAttributeThrowsExceptionIfClassDoesNotExist(): void
-    {
-        $this->expectException(Exception::class);
-
-        $this->assertClassHasStaticAttribute('attribute', ClassThatDoesNotExist::class);
-    }
-
-    public function testAssertClassNotHasStaticAttributeThrowsExceptionIfAttributeNameIsNotValid(): void
-    {
-        $this->expectException(Exception::class);
-
-        $this->assertClassNotHasStaticAttribute('1', ClassWithNonPublicAttributes::class);
-    }
-
-    public function testAssertClassNotHasStaticAttributeThrowsExceptionIfClassDoesNotExist(): void
-    {
-        $this->expectException(Exception::class);
-
-        $this->assertClassNotHasStaticAttribute('attribute', ClassThatDoesNotExist::class);
-    }
-
-    public function testAssertObjectHasAttributeThrowsException2(): void
-    {
-        $this->expectException(Exception::class);
-
-        $this->assertObjectHasAttribute('foo', null);
-    }
-
-    public function testAssertObjectHasAttributeThrowsExceptionIfAttributeNameIsNotValid(): void
-    {
-        $this->expectException(Exception::class);
-
-        $this->assertObjectHasAttribute('1', ClassWithNonPublicAttributes::class);
-    }
-
-    public function testAssertObjectNotHasAttributeThrowsException2(): void
-    {
-        $this->expectException(Exception::class);
-
-        $this->assertObjectNotHasAttribute('foo', null);
-    }
-
-    public function testAssertObjectNotHasAttributeThrowsExceptionIfAttributeNameIsNotValid(): void
-    {
-        $this->expectException(Exception::class);
-
-        $this->assertObjectNotHasAttribute('1', ClassWithNonPublicAttributes::class);
-    }
-
-    public function testClassHasPublicAttribute(): void
-    {
-        $this->assertClassHasAttribute('publicAttribute', ClassWithNonPublicAttributes::class);
-
-        $this->expectException(AssertionFailedError::class);
-
-        $this->assertClassHasAttribute('attribute', ClassWithNonPublicAttributes::class);
-    }
-
-    public function testClassNotHasPublicAttribute(): void
-    {
-        $this->assertClassNotHasAttribute('attribute', ClassWithNonPublicAttributes::class);
-
-        $this->expectException(AssertionFailedError::class);
-
-        $this->assertClassNotHasAttribute('publicAttribute', ClassWithNonPublicAttributes::class);
-    }
-
-    public function testClassHasPublicStaticAttribute(): void
-    {
-        $this->assertClassHasStaticAttribute('publicStaticAttribute', ClassWithNonPublicAttributes::class);
-
-        $this->expectException(AssertionFailedError::class);
-
-        $this->assertClassHasStaticAttribute('attribute', ClassWithNonPublicAttributes::class);
-    }
-
-    public function testClassNotHasPublicStaticAttribute(): void
-    {
-        $this->assertClassNotHasStaticAttribute('attribute', ClassWithNonPublicAttributes::class);
-
-        $this->expectException(AssertionFailedError::class);
-
-        $this->assertClassNotHasStaticAttribute('publicStaticAttribute', ClassWithNonPublicAttributes::class);
-    }
-
-    public function testObjectHasPublicAttribute(): void
-    {
-        $obj = new ClassWithNonPublicAttributes;
-
-        $this->assertObjectHasAttribute('publicAttribute', $obj);
-
-        $this->expectException(AssertionFailedError::class);
-
-        $this->assertObjectHasAttribute('attribute', $obj);
-    }
-
-    public function testObjectNotHasPublicAttribute(): void
-    {
-        $obj = new ClassWithNonPublicAttributes;
-
-        $this->assertObjectNotHasAttribute('attribute', $obj);
-
-        $this->expectException(AssertionFailedError::class);
-
-        $this->assertObjectNotHasAttribute('publicAttribute', $obj);
-    }
-
-    public function testObjectHasOnTheFlyAttribute(): void
-    {
-        $obj      = new stdClass;
-        $obj->foo = 'bar';
-
-        $this->assertObjectHasAttribute('foo', $obj);
-
-        $this->expectException(AssertionFailedError::class);
-
-        $this->assertObjectHasAttribute('bar', $obj);
-    }
-
-    public function testObjectNotHasOnTheFlyAttribute(): void
-    {
-        $obj      = new stdClass;
-        $obj->foo = 'bar';
-
-        $this->assertObjectNotHasAttribute('bar', $obj);
-
-        $this->expectException(AssertionFailedError::class);
-
-        $this->assertObjectNotHasAttribute('foo', $obj);
-    }
-
-    public function testObjectHasProtectedAttribute(): void
-    {
-        $obj = new ClassWithNonPublicAttributes;
-
-        $this->assertObjectHasAttribute('protectedAttribute', $obj);
-
-        $this->expectException(AssertionFailedError::class);
-
-        $this->assertObjectHasAttribute('attribute', $obj);
-    }
-
-    public function testObjectNotHasProtectedAttribute(): void
-    {
-        $obj = new ClassWithNonPublicAttributes;
-
-        $this->assertObjectNotHasAttribute('attribute', $obj);
-
-        $this->expectException(AssertionFailedError::class);
-
-        $this->assertObjectNotHasAttribute('protectedAttribute', $obj);
-    }
-
-    public function testObjectHasPrivateAttribute(): void
-    {
-        $obj = new ClassWithNonPublicAttributes;
-
-        $this->assertObjectHasAttribute('privateAttribute', $obj);
-
-        $this->expectException(AssertionFailedError::class);
-
-        $this->assertObjectHasAttribute('attribute', $obj);
-    }
-
-    public function testObjectNotHasPrivateAttribute(): void
-    {
-        $obj = new ClassWithNonPublicAttributes;
-
-        $this->assertObjectNotHasAttribute('attribute', $obj);
-
-        $this->expectException(AssertionFailedError::class);
-
-        $this->assertObjectNotHasAttribute('privateAttribute', $obj);
-    }
-
     /**
      * @doesNotPerformAssertions
      */
@@ -1258,30 +977,6 @@ XML;
         $this->assertThat(['foo' => 'bar'], $this->arrayHasKey('foo'));
     }
 
-    public function testAssertThatClassHasAttribute(): void
-    {
-        $this->assertThat(
-            new ClassWithNonPublicAttributes,
-            $this->classHasAttribute('publicAttribute')
-        );
-    }
-
-    public function testAssertThatClassHasStaticAttribute(): void
-    {
-        $this->assertThat(
-            new ClassWithNonPublicAttributes,
-            $this->classHasStaticAttribute('publicStaticAttribute')
-        );
-    }
-
-    public function testAssertThatObjectHasAttribute(): void
-    {
-        $this->assertThat(
-            new ClassWithNonPublicAttributes,
-            $this->objectHasAttribute('publicAttribute')
-        );
-    }
-
     public function testAssertThatEqualTo(): void
     {
         $this->assertThat('foo', $this->equalTo('foo'));
