@@ -21,7 +21,7 @@ final class LogicalExpressionsTest extends TestCase
     {
         $constraint = new LogicalNot(
             LogicalAnd::fromConstraints(
-                new IsNull(),
+                new IsNull,
             )
         );
 
@@ -70,7 +70,7 @@ final class LogicalExpressionsTest extends TestCase
     {
         $constraint = new LogicalNot(
             LogicalOr::fromConstraints(
-                new IsNull(),
+                new IsNull,
             )
         );
 
@@ -91,7 +91,7 @@ final class LogicalExpressionsTest extends TestCase
     {
         $constraint = new LogicalNot(
             LogicalOr::fromConstraints(
-                new IsNull(),
+                new IsNull,
                 new IsType('int'),
                 new IsType('array')
             )
@@ -118,7 +118,7 @@ final class LogicalExpressionsTest extends TestCase
     {
         $constraint = new LogicalNot(
             LogicalXor::fromConstraints(
-                new IsNull(),
+                new IsNull,
             )
         );
 
