@@ -15,7 +15,6 @@ use ArrayObject;
 use Countable;
 use PHPUnit\Framework\Constraint\Count;
 use PHPUnit\Framework\Constraint\SameSize;
-use PHPUnit\TestFixture\ClassWithNonPublicAttributes;
 use PHPUnit\TestFixture\DummyException;
 use PHPUnit\TestFixture\TestIterator;
 use PHPUnit\Util\Filter;
@@ -883,186 +882,6 @@ EOF
         $this->fail();
     }
 
-    public function testConstraintClassNotHasAttribute(): void
-    {
-        $constraint = Assert::logicalNot(
-            Assert::classHasAttribute('privateAttribute')
-        );
-
-        $this->assertTrue($constraint->evaluate(stdClass::class, '', true));
-        $this->assertFalse($constraint->evaluate(ClassWithNonPublicAttributes::class, '', true));
-        $this->assertEquals('does not have attribute "privateAttribute"', $constraint->toString());
-        $this->assertCount(1, $constraint);
-
-        try {
-            $constraint->evaluate(ClassWithNonPublicAttributes::class);
-        } catch (ExpectationFailedException $e) {
-            $this->assertEquals(
-                sprintf(
-                    <<<'EOF'
-Failed asserting that class "%s" does not have attribute "privateAttribute".
-
-EOF
-                    ,
-                    ClassWithNonPublicAttributes::class
-                ),
-                TestFailure::exceptionToString($e)
-            );
-
-            return;
-        }
-
-        $this->fail();
-    }
-
-    public function testConstraintClassNotHasAttribute2(): void
-    {
-        $constraint = Assert::logicalNot(
-            Assert::classHasAttribute('privateAttribute')
-        );
-
-        try {
-            $constraint->evaluate(ClassWithNonPublicAttributes::class, 'custom message');
-        } catch (ExpectationFailedException $e) {
-            $this->assertEquals(
-                sprintf(
-                    <<<'EOF'
-custom message
-Failed asserting that class "%s" does not have attribute "privateAttribute".
-
-EOF
-                    ,
-                    ClassWithNonPublicAttributes::class
-                ),
-                TestFailure::exceptionToString($e)
-            );
-
-            return;
-        }
-
-        $this->fail();
-    }
-
-    public function testConstraintClassNotHasStaticAttribute(): void
-    {
-        $constraint = Assert::logicalNot(
-            Assert::classHasStaticAttribute('privateStaticAttribute')
-        );
-
-        $this->assertTrue($constraint->evaluate(stdClass::class, '', true));
-        $this->assertFalse($constraint->evaluate(ClassWithNonPublicAttributes::class, '', true));
-        $this->assertEquals('does not have static attribute "privateStaticAttribute"', $constraint->toString());
-        $this->assertCount(1, $constraint);
-
-        try {
-            $constraint->evaluate(ClassWithNonPublicAttributes::class);
-        } catch (ExpectationFailedException $e) {
-            $this->assertEquals(
-                sprintf(
-                    <<<'EOF'
-Failed asserting that class "%s" does not have static attribute "privateStaticAttribute".
-
-EOF
-                    ,
-                    ClassWithNonPublicAttributes::class
-                ),
-                TestFailure::exceptionToString($e)
-            );
-
-            return;
-        }
-
-        $this->fail();
-    }
-
-    public function testConstraintClassNotHasStaticAttribute2(): void
-    {
-        $constraint = Assert::logicalNot(
-            Assert::classHasStaticAttribute('privateStaticAttribute')
-        );
-
-        try {
-            $constraint->evaluate(ClassWithNonPublicAttributes::class, 'custom message');
-        } catch (ExpectationFailedException $e) {
-            $this->assertEquals(
-                sprintf(
-                    <<<'EOF'
-custom message
-Failed asserting that class "%s" does not have static attribute "privateStaticAttribute".
-
-EOF
-                    ,
-                    ClassWithNonPublicAttributes::class
-                ),
-                TestFailure::exceptionToString($e)
-            );
-
-            return;
-        }
-
-        $this->fail();
-    }
-
-    public function testConstraintObjectNotHasAttribute(): void
-    {
-        $constraint = Assert::logicalNot(
-            Assert::objectHasAttribute('privateAttribute')
-        );
-
-        $this->assertTrue($constraint->evaluate(new stdClass, '', true));
-        $this->assertFalse($constraint->evaluate(new ClassWithNonPublicAttributes, '', true));
-        $this->assertEquals('does not have attribute "privateAttribute"', $constraint->toString());
-        $this->assertCount(1, $constraint);
-
-        try {
-            $constraint->evaluate(new ClassWithNonPublicAttributes);
-        } catch (ExpectationFailedException $e) {
-            $this->assertEquals(
-                sprintf(
-                    <<<'EOF'
-Failed asserting that object of class "%s" does not have attribute "privateAttribute".
-
-EOF
-                    ,
-                    ClassWithNonPublicAttributes::class
-                ),
-                TestFailure::exceptionToString($e)
-            );
-
-            return;
-        }
-
-        $this->fail();
-    }
-
-    public function testConstraintObjectNotHasAttribute2(): void
-    {
-        $constraint = Assert::logicalNot(
-            Assert::objectHasAttribute('privateAttribute')
-        );
-
-        try {
-            $constraint->evaluate(new ClassWithNonPublicAttributes, 'custom message');
-        } catch (ExpectationFailedException $e) {
-            $this->assertEquals(
-                sprintf(
-                    <<<'EOF'
-custom message
-Failed asserting that object of class "%s" does not have attribute "privateAttribute".
-
-EOF
-                    ,
-                    ClassWithNonPublicAttributes::class
-                ),
-                TestFailure::exceptionToString($e)
-            );
-
-            return;
-        }
-
-        $this->fail();
-    }
-
     /**
      * @testdox Constraint PCRE not match
      */
