@@ -25,6 +25,7 @@ use PHPUnit\TestFixture\ExceptionWithThrowable;
 use PHPUnit\TestFixture\FinalClass;
 use PHPUnit\TestFixture\InterfaceWithSemiReservedMethodName;
 use PHPUnit\TestFixture\MockObject\AbstractMockTestClass;
+use PHPUnit\TestFixture\MockObject\ReadonlyClass;
 use PHPUnit\TestFixture\SingletonClass;
 use RuntimeException;
 use stdClass;
@@ -325,6 +326,17 @@ final class GeneratorTest extends TestCase
         $this->createMock(FinalClass::class);
     }
 
+    /**
+     * @requires PHP 8.2
+     */
+    public function testCannotMockReadonlyClass(): void
+    {
+        $this->expectException(ClassIsReadonlyException::class);
+
+        /* @noinspection ClassMockingCorrectnessInspection */
+        $this->createMock(ReadonlyClass::class);
+    }
+
     public function testCanDoubleIntersectionOfMultipleInterfaces(): void
     {
         $stub = $this->generator->getMockForInterfaces(
