@@ -10,9 +10,6 @@
 namespace PHPUnit\Framework\MockObject;
 
 use PHPUnit\Framework\TestCase;
-use PHPUnit\TestFixture\MockObject\ClassWithoutParentButParentReturnType;
-use ReflectionClass;
-use RuntimeException;
 use SebastianBergmann\Type\UnknownType;
 
 /**
@@ -38,15 +35,4 @@ final class MockMethodTest extends TestCase
         );
         $this->assertEquals('methodName', $method->getName());
     }
-
-    /**
-     * @requires PHP < 7.4
-     */
-    public function testFailWhenReturnTypeIsParentButThereIsNoParentClass(): void
-    {
-        $class = new ReflectionClass(ClassWithoutParentButParentReturnType::class);
-
-        $this->expectException(RuntimeException::class);
-        MockMethod::fromReflection($class->getMethod('foo'), false, false);
-    }
 }
